chacha20poly1305: fix style nits in variable names

Change-Id: I3ac9dc7bf1c1c6ff39b3385cbf965dfb57f8327a
Reviewed-on: https://go-review.googlesource.com/43511
Reviewed-by: Ian Lance Taylor <iant@golang.org>
diff --git a/chacha20poly1305/chacha20poly1305_amd64.go b/chacha20poly1305/chacha20poly1305_amd64.go
index 1e523b9..7cd7ad8 100644
--- a/chacha20poly1305/chacha20poly1305_amd64.go
+++ b/chacha20poly1305/chacha20poly1305_amd64.go
@@ -26,15 +26,15 @@
 )
 
 func init() {
-	detectCpuFeatures()
+	detectCPUFeatures()
 }
 
 // detectCpuFeatures is used to detect if cpu instructions
 // used by the functions implemented in assembler in
 // chacha20poly1305_amd64.s are supported.
-func detectCpuFeatures() {
-	maxId, _, _, _ := cpuid(0, 0)
-	if maxId < 1 {
+func detectCPUFeatures() {
+	maxID, _, _, _ := cpuid(0, 0)
+	if maxID < 1 {
 		return
 	}
 
@@ -54,7 +54,7 @@
 	}
 	haveAVX := isSet(28, ecx1) && osSupportsAVX
 
-	if maxId < 7 {
+	if maxID < 7 {
 		return
 	}
@@ -26,15 +26,15 @@
 }
 
-// detectCpuFeatures is used to detect if cpu instructions
+// detectCPUFeatures is used to detect if cpu instructions
 // used by the functions implemented in assembler in
 // chacha20poly1305_amd64.s are supported.